@@ -8,7 +8,7 @@ use Scalar::Util qw( looks_like_number );
 
 # ABSTRACT: Get raw hashrefs from a resultset with utf-8 flag
 
-our $VERSION = '1.000003'; # VERSION
+our $VERSION = '1.000004'; # VERSION
 
 
 use parent qw( DBIx::Class::ResultClass::HashRefInflator );
@@ -22,7 +22,7 @@ sub inflate_result {
     return {
         map {
             my $val = $res->{$_};
-            utf8::decode($val)  if defined $val && !ref($val) && !looks_like_number($val);
+            utf8::decode($val)  unless looks_like_number($val);
             ( $_ => $val );
         } keys %$res
     };
@@ -42,7 +42,7 @@ DBIx::Class::ResultClass::HashRefInflator::UTF8 - Get raw hashrefs from a result
 
 =head1 VERSION
 
-version 1.000003
+version 1.000004
 
 =head1 SYNOPSIS
 
@@ -102,7 +102,7 @@ following:
  my $artist = $artitsts_rs->search({}, {prefetch => 'cds' })->first;
 
  my $cds = $artist->cds;
- $cds->result_class('DBIx::Class::ResultClass::HashRefInflator');
+ $cds->result_class('DBIx::Class::ResultClass::HashRefInflator::UTF8');
  my $first = $cds->first;
 
 C<$first> will B<not> be a hashref, it will be a normal CD row since
